function d = dependence(T)
// Returns a normalized vector with the dependence of the nodes of a graph.
//
// Calling Sequence
//   dependence(I) // Show the dependences of the matrix I, always needs the parameter I.
//   d = dependence(I) // Store the dependences of the matrix I in the vector d.
//
// Parameters
// I: Matrix to calculate the dependence vector.
// d: Name of the vector to store the dependence vector.
//
// Description
// This function gives the sum of the rows of the given matrix, that is the dependence vector. Note that this works for any matrix, even if have polynomial entries.
//
// Examples
// I=[1 0 1;0 2 0;0 0 0]
// d = dependence(I)
//
// See also
//  influence
//  micmac
//  pagerank
//  pwp
//  heatkernel
//
// Authors
//  Jorge Catumba ;
// Bibliography
//   Indirect Influences, Rafael Díaz, preprint http://arxiv.org/abs/0906.1610v1
//   Cálculo de Influencias Indirectas en Scilab. Rafael Díaz, Jorge Catumba.

  i=size(T,"r")
  
  for var=1:i
    d(1,var)=sum(T(var,:))
  end
endfunction