function f = influence(T)
// Returns a normalized vector with the influence of the nodes of a graph.
//
// Calling Sequence
//   influence(I) // Show the influences of the matrix I, always needs the parameter I.
//   d = influence(I) // Store the influences of the matrix I in the vector f.
//
// Parameters
// I: Matrix to calculate the dependence vector.
// f: Name of the vector to store the influence vector.
//
// Description
// This function gives the sum of the columns of the given matrix, that is the influence vector. Note that this works for any matrix, even if have polynomial entries.
//
// Examples
// I=[1 0 1;0 2 0;0 0 0]
// f = influence(I)
//
// See also
//  dependence
//  micmac
//  pagerank
//  pwp
//  heatkernel
//
// Authors
//  Jorge Catumba ;
// Bibliography
//   Indirect Influences, Rafael Díaz, preprint http://arxiv.org/abs/0906.1610v1
//   Cálculo de Influencias Indirectas en Scilab. Rafael Díaz, Jorge Catumba.

  j=size(T,"c")
    
  for var=1:j
    f(1,var)=sum(T(:,var))
  end
endfunction